@@ -25,6 +25,8 @@ class CompanySECModel(Base):
     is_activated = Column(Boolean, nullable=True)
     is_biopharma = Column(Boolean, nullable=True)
     discarded = Column(Boolean, nullable=True)
+    skip_sec = Column(Boolean, nullable=True)
+    last_crawl_date = Column(DateTime, nullable=True)
     updated_at = Column(
         DateTime,
         default=datetime.utcnow,
