@@ -19,6 +19,8 @@ class CompanySECResourceSchema(Schema):
     is_activated = fields.Boolean(allow_none=True)
     is_biopharma = fields.Boolean(allow_none=True)
     discarded = fields.Boolean(allow_none=True)
+    skip_sec = fields.Boolean(allow_none=True)
+    last_crawl_date = fields.DateTime(allow_none=True)
     updated_at = fields.DateTime(dump_only=True)
 
 
@@ -30,4 +32,6 @@ class CompanySECUpdateSchema(Schema):
     is_activated = fields.Boolean(allow_none=True)
     is_biopharma = fields.Boolean(allow_none=True)
     discarded = fields.Boolean(allow_none=True)
+    skip_sec = fields.Boolean(allow_none=True)
+    last_crawl_date = fields.DateTime(allow_none=True)
     updated_at = fields.DateTime(dump_only=True)
