@@ -21,7 +21,11 @@ class InterventionNCTModel(Base):
         ForeignKey('interventions.id'),
         nullable=False,
     )
-    nct_id = Column(String(128), nullable=False, index=True)
+    nct_study_id = Column(
+        Integer,
+        ForeignKey('nct_study.id'),
+        nullable=False,
+    )
     match_score = Column(Float, nullable=False)
     updated_at = Column(
         DateTime,
